==> distribution-5.52.0.zip: drr/enrichment/upi/functions/Existing_Upi.java <==
package drr.enrichment.upi.functions;

import cdm.base.staticdata.asset.common.ProductIdTypeEnum;
import cdm.base.staticdata.asset.common.ProductIdentifier;
import cdm.base.staticdata.asset.common.metafields.ReferenceWithMetaProductIdentifier;
import cdm.product.template.ContractualProduct;
import cdm.product.template.Product;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperC;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.metafields.FieldWithMetaString;
import drr.regulation.common.ReportableEvent;
import drr.regulation.common.functions.ProductForEvent;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(Existing_Upi.Existing_UpiDefault.class)
public abstract class Existing_Upi implements RosettaFunction {
	
	// RosettaFunction dependencies
	//
	@Inject protected ProductForEvent productForEvent;

	/**
	* @param reportableEvent 
	* @return existingUpi 
	*/
	public String evaluate(ReportableEvent reportableEvent) {
		String existingUpi = doEvaluate(reportableEvent);
		
		return existingUpi;
	}

	protected abstract String doEvaluate(ReportableEvent reportableEvent);

	protected abstract MapperS<? extends Product> product(ReportableEvent reportableEvent);

	public static class Existing_UpiDefault extends Existing_Upi {
		@Override
		protected String doEvaluate(ReportableEvent reportableEvent) {
			String existingUpi = null;
			return assignOutput(existingUpi, reportableEvent);
		}
		
		protected String assignOutput(String existingUpi, ReportableEvent reportableEvent) {
			final MapperC<ReferenceWithMetaProductIdentifier> thenArg0 = product(reportableEvent).<ContractualProduct>map("getContractualProduct", _product -> _product.getContractualProduct()).<ReferenceWithMetaProductIdentifier>mapC("getProductIdentifier", contractualProduct -> contractualProduct.getProductIdentifier())
				.filterItemNullSafe(item -> areEqual(item.<ProductIdentifier>map("Type coercion", _referenceWithMetaProductIdentifier -> _referenceWithMetaProductIdentifier == null ? null : _referenceWithMetaProductIdentifier.getValue()).<ProductIdTypeEnum>map("getSource", productIdentifier -> productIdentifier.getSource()), MapperS.of(ProductIdTypeEnum.UPI), CardinalityOperator.All).get());
			final MapperS<ReferenceWithMetaProductIdentifier> thenArg1 = MapperS.of(thenArg0.get());
			final FieldWithMetaString fieldWithMetaString = thenArg1.<ProductIdentifier>map("Type coercion", referenceWithMetaProductIdentifier -> referenceWithMetaProductIdentifier == null ? null : referenceWithMetaProductIdentifier.getValue()).<FieldWithMetaString>map("getIdentifier", productIdentifier -> productIdentifier.getIdentifier()).get();
			if (fieldWithMetaString == null) {
				existingUpi = null;
			} else {
				existingUpi = fieldWithMetaString.getValue();
			}
			
			return existingUpi;
		}
		
		@Override
		protected MapperS<? extends Product> product(ReportableEvent reportableEvent) {
			return MapperS.of(productForEvent.evaluate(reportableEvent));
		}
	}
}

==> distribution-5.55.0.zip: drr/enrichment/upi/functions/Existing_Upi.java <==
package drr.enrichment.upi.functions;

import cdm.base.staticdata.asset.common.ProductIdTypeEnum;
import cdm.base.staticdata.asset.common.ProductIdentifier;
import cdm.base.staticdata.asset.common.metafields.ReferenceWithMetaProductIdentifier;
import cdm.product.template.ContractualProduct;
import cdm.product.template.Product;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.expression.CardinalityOperator;
import com.rosetta.model.lib.functions.RosettaFunction;
import com.rosetta.model.lib.mapper.MapperC;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.metafields.FieldWithMetaString;
import drr.regulation.common.ReportableEvent;
import drr.regulation.common.functions.ProductForEvent;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.*;

@ImplementedBy(Existing_Upi.Existing_UpiDefault.class)
public abstract class Existing_Upi implements RosettaFunction {
	
	// RosettaFunction dependencies
	//
	@Inject protected ProductForEvent productForEvent;

	/**
	* @param reportableEvent 
	* @return existingUpi 
	*/
	public String evaluate(ReportableEvent reportableEvent) {
		String existingUpi = doEvaluate(reportableEvent);
		
		return existingUpi;
	}

	protected abstract String doEvaluate(ReportableEvent reportableEvent);

	protected abstract MapperS<? extends Product> product(ReportableEvent reportableEvent);

	public static class Existing_UpiDefault extends Existing_Upi {
		@Override
		protected String doEvaluate(ReportableEvent reportableEvent) {
			String existingUpi = null;
			return assignOutput(existingUpi, reportableEvent);
		}
		
		protected String assignOutput(String existingUpi, ReportableEvent reportableEvent) {
			final MapperC<ReferenceWithMetaProductIdentifier> thenArg0 = product(reportableEvent).<ContractualProduct>map("getContractualProduct", _product -> _product.getContractualProduct()).<ReferenceWithMetaProductIdentifier>mapC("getProductIdentifier", contractualProduct -> contractualProduct.getProductIdentifier())
				.filterItemNullSafe(item -> areEqual(item.<ProductIdentifier>map("Type coercion", _referenceWithMetaProductIdentifier -> _referenceWithMetaProductIdentifier == null ? null : _referenceWithMetaProductIdentifier.getValue()).<ProductIdTypeEnum>map("getSource", productIdentifier -> productIdentifier.getSource()), MapperS.of(ProductIdTypeEnum.UPI), CardinalityOperator.All).get());
			final MapperS<ReferenceWithMetaProductIdentifier> thenArg1 = MapperS.of(thenArg0.get());
			final FieldWithMetaString fieldWithMetaString = thenArg1.<ProductIdentifier>map("Type coercion", referenceWithMetaProductIdentifier -> referenceWithMetaProductIdentifier == null ? null : referenceWithMetaProductIdentifier.getValue()).<FieldWithMetaString>map("getIdentifier", productIdentifier -> productIdentifier.getIdentifier()).get();
			if (fieldWithMetaString == null) {
				existingUpi = null;
			} else {
				existingUpi = fieldWithMetaString.getValue();
			}
			
			return existingUpi;
		}
		
		@Override
		protected MapperS<? extends Product> product(ReportableEvent reportableEvent) {
			return MapperS.of(productForEvent.evaluate(reportableEvent));
		}
	}
}
